LIF
---
A Leaky Integrate Fire (LIF) layer and variations thereof.

.. currentmodule:: sinabs.layers

.. autoclass:: LIF
    :members:

LIFRecurrent
------------
.. autoclass:: LIFRecurrent
    :members:

LIFSqueeze
----------
.. autoclass:: LIFSqueeze
    :members:
